@@ -78,7 +78,7 @@
 */
 
 /*
- * @(#) $Id: libpbs.h 5713 2012-02-07 18:13:11Z ataufer $
+ * @(#) $Id: libpbs.h 4712 2011-06-07 20:42:21Z ataufer $
  */
 
 /* libpbs.h
@@ -100,16 +100,15 @@
 #include "pbs_ifl.h"
 #include "list_link.h"
 #include "pbs_error.h"
-#include "server_limits.h" /* Pulls in PBS_NET_MAX_CONNECTIONS */
 
 #ifndef LIBPBS_H
 #define LIBPBS_H
 
 #define PBS_BATCH_PROT_TYPE 2
-#define PBS_BATCH_PROT_VER 1
+#define PBS_BATCH_PROT_VER 2
 /* #define PBS_REQUEST_MAGIC (56) */
 /* #define PBS_REPLY_MAGIC   (57) */
-#define SCRIPT_CHUNK_Z (65536)
+#define SCRIPT_CHUNK_Z (4096)
 #ifndef TRUE
 #define TRUE 1
 #define FALSE 0
@@ -146,7 +145,7 @@ extern char pbs_current_group[];
 /* set ENABLE_TRUSTED_AUTH to "TRUE" to bypass using pbs_iff for authentication */
 #define ENABLE_TRUSTED_AUTH FALSE
 
-#define NCONNECTS PBS_NET_MAX_CONNECTIONS
+#define NCONNECTS 10
 
 struct connect_handle
   {
