@@ -150,13 +150,16 @@ extern int   chk_file_sec_stderr;
 
 
 extern void log_close (int);
+extern void job_log_close (int);
 extern void log_err (int, char *, char *);
 extern void log_ext (int,char *,char *,int);
 extern void log_event (int, int, char *, char *);
 extern int  log_open (char *, char *);
+extern int  job_log_open (char *, char *);
 extern void log_record (int, int, char *, char *);
 extern void log_roll (int);
 extern long log_size (void);
+extern long job_log_size (void);
 extern int  log_remove_old (char *,unsigned long);
 extern char log_buffer[LOG_BUF_SIZE];
 int log_init (char *, char *);
