@@ -181,11 +181,9 @@ extern struct passwd *check_pwd(job *);
 extern int   send_sisters(job *, int);
 extern int   task_save(task *) ;
 extern void  DIS_rpp_reset(void);
-extern void  checkret(char **, int);
+extern void  checkret(char **, long);
 extern char *get_job_envvar(job *, char *);
 extern int   mom_open_socket_to_jobs_server(job* pjob, char *id, void (*message_hander)(int));
-void         clear_servers();
-void remove_defunct_cpusets();
 
 /* defined in mach-dependant mom_mach.c */
 extern int kill_task(struct task *, int, int);
