@@ -107,6 +107,7 @@
 #define ATTR_u "User_List"
 #define ATTR_v "Variable_List"
 #define ATTR_A "Account_Name"
+#define ATTR_args "job_arguments"
 #define ATTR_M "Mail_Users"
 #define ATTR_N "Job_Name"
 #define ATTR_S "Shell_Path_List"
@@ -115,6 +116,8 @@
 #define ATTR_stagein  "stagein"
 #define ATTR_stageout "stageout"
 #define ATTR_jobtype  "jobtype"
+#define ATTR_submit_host "submit_host"
+#define ATTR_init_work_dir "init_work_dir"
 
 /* additional job and general attribute names */
 
@@ -164,11 +167,17 @@
 #define ATTR_P           "proxy_user"
 #define ATTR_node_exclusive "node_exclusive"
 #define ATTR_exec_gpus   "exec_gpus"
+#define ATTR_J           "job_id"
 
 #ifdef USEJOBCREATE
 #define ATTR_pagg         "pagg_id"
 #endif /* USEJOBCREATE */
 
+#ifdef NVIDIA_GPUS
+  /* JOB_ATR_gpu_flags */
+#define ATTR_gpu_flags		"gpu_flags"
+#endif  /* NVIDIA_GPUS */
+
 /* additional queue attributes names */
 
 #define ATTR_aclgren    "acl_group_enable"
@@ -303,6 +312,8 @@
 #define ATTR_NODE_num_numa_nodes "num_numa_nodes"
 #define ATTR_NODE_numa_str       "numa_node_str"
 #define ATTR_NODE_gpus           "gpus"
+#define ATTR_NODE_gpustatus      "gpu_status"
+#define ATTR_NODE_gpus_str       "numa_gpu_node_str"
 
 /* notification email formating */
 #define ATTR_mailsubjectfmt "mail_subject_fmt"
@@ -326,8 +337,8 @@
 #define EXECQUEONLY  "exec_queue_only"   /* see req_stat.c */
 #define RERUNFORCE "force"
 
-#define USER_HOLD "u"
-#define OTHER_HOLD "o"
+#define USER_HOLD   "u"
+#define OTHER_HOLD  "o"
 #define SYSTEM_HOLD "s"
 
 /* node-attribute values (state,ntype) */
@@ -407,6 +418,7 @@
 
 #define PBS_MAXUSER  32 /* max user name length */
 #define PBS_MAXGRPN  16 /* max group name length */
+#define PBS_MAXGPUID 16 /* max gpu id length */
 #define PBS_MAXQUEUENAME 15 /* max queue name length */
 #define PBS_MAXSERVERNAME PBS_MAXHOSTNAME /* max server name length */
 #define PBS_MAXJOBARRAYLEN      7       /* number of characters allowed in jobarray portion of job id, including '[]' */
@@ -424,8 +436,8 @@
 
 #define PBS_MAXCREDENTIAL_LEN 2048 /* Maximum authentication credential length. */
 /* constants used to indicate version of job ji_qs struct written to disk.
-   starting with 2.4.0 we stopped encoding the torque version number into the 
-   hex value e.g. 0x00020300 for torque v2.3.0. Now we just increment a value 
+   starting with 2.4.0 we stopped encoding the torque version number into the
+   hex value e.g. 0x00020300 for torque v2.3.0. Now we just increment a value
    which is added to the last version encoded that way */
 #define PBS_QS_VERSION_BASE 0x00020300 /* magic number do not change */
 #define PBS_QS_VERSION_INT 2 /* increment this version number with every change to the ji_qs struct */
@@ -473,7 +485,7 @@
 
 #define NO_MOM_RELAY 1
 
-enum batch_op { SET, UNSET, INCR, DECR, EQ, NE, GE, GT, LE, LT, DFLT, MERGE };
+enum batch_op { SET, UNSET, INCR, DECR, EQ, NE, GE, GT, LE, LT, DFLT, MERGE, INCR_OLD };
 
 /*
 ** This structure is identical to attropl so they can be used
@@ -617,6 +629,8 @@ extern int
 extern int
   usepool(int connect, int update);
 
+extern int pbs_gpumode(int connect, char *node, char *gpuid, int gpumode);
+
 #endif /* _PBS_IFL_DEF */
 
 /*  end of pbs_ifl.h  */
