@@ -349,6 +349,11 @@ enum job_atr
 #ifdef USEJOBCREATE
   JOB_ATR_pagg_id,
 #endif /* USEJOBCREATE */
+  JOB_ATR_job_id,
+#ifdef NVIDIA_GPUS
+  JOB_ATR_gpu_flags,		/* gpu flags - mode and reset flags */
+#endif  /* NVIDIA_GPUS */
+  JOB_ATR_arguments,
 #include "site_job_attr_enum.h"
 
   JOB_ATR_UNKN,  /* the special "unknown" type    */
@@ -597,9 +602,9 @@ struct job
       struct   /* if in execution queue .. */
         {
         pbs_net_t ji_momaddr;  /* host addr of Server */
+        int       ji_exitstat; /* job exit status from MOM */
         unsigned short ji_momport;  /* host port of Server default 15002 */
         unsigned short ji_mom_rmport; /* host mom manager port of Server default 15003 */
-        int       ji_exitstat; /* job exit status from MOM */
         } ji_exect;
 
       struct
@@ -726,6 +731,27 @@ typedef struct infoent
   list_link ie_next; /* link to next one */
   } infoent;
 
+
+
+
+
+#ifdef PBS_MOM
+typedef struct job_file_delete_info
+  {
+  char           jobid[PBS_MAXSVRJOBID+1];
+  char           prefix[PBS_JOBBASE + 1];
+  char          *checkpoint_dir;
+  unsigned char  has_temp_dir;
+  unsigned char  has_node_file;
+  gid_t          gid;
+  uid_t          uid;
+  } job_file_delete_info;
+#endif
+
+
+
+
+
 #define TI_FLAGS_INIT           1  /* task has called tm_init */
 #define TI_FLAGS_CHECKPOINT     2  /* task has checkpointed */
 
