@@ -97,6 +97,10 @@
 
 #include "server_limits.h"
 
+#ifndef ulong
+#define ulong unsigned long
+#endif
+
 #define NO_BUFFER_SPACE -2
 #define NO_ATTR_DATA    1
 #define ATTR_NOT_FOUND  -2
@@ -185,7 +189,7 @@ enum srv_atr
   SRV_ATR_RecordJobScript,
   SRV_ATR_JobLogFileMaxSize,
   SRV_ATR_JobLogFileRollDepth,
-  SRV_ATR_JobLogKeepDays,
+  SRV_ATR_JobLogKeepDays,        /* 80 */
 #ifdef MUNGE_AUTH
   SRV_ATR_authusers,
 #endif
