@@ -181,12 +181,14 @@ decode_b(
  */
 /*ARGSUSED*/
 
-int encode_b(attr, phead, atname, rsname, mode)
-attribute *attr;  /* ptr to attribute */
-tlist_head *phead;  /* head of attribute list */
-char  *atname; /* attribute name */
-char  *rsname; /* resource name or null */
-int   mode;  /* encode mode, unused here */
+int
+encode_b(
+  attribute *attr,  /* ptr to attribute */
+  tlist_head *phead,  /* head of attribute list */
+  char *atname, /* attribute name */
+  char *rsname, /* resource name or null */
+  int mode  /* encode mode, unused here */
+)
   {
   size_t   ct;
   svrattrl *pal;
