@@ -222,6 +222,7 @@ void append_link(
     abort();
     }  /* END if ((pobj == NULL) || ...) */
 
+
 #endif  /* NDEBUG */
 
   /*
@@ -344,6 +345,22 @@ is_linked(list_link *head, list_link *entry)
   }
 
 
+/*
+ * returns 1 if the link points to something other than itself, 0 otherwise
+ * (links that have been cleared with the CLEAR_LINK macro will return 0)
+ *
+ */
+int is_link_initialized(
+    
+  list_link *head)
+
+  {
+  if ((head->ll_prior != head) ||
+      (head->ll_next  != head))
+    return(1);
+
+  return(0);
+  }
 
 
 /*
@@ -420,3 +437,23 @@ list_move(tlist_head *from, tlist_head *to)
     CLEAR_HEAD((*from));
     }
   }
+
+/**
+ * free a linked pid list
+ *
+ * @param pl - a pointer to a linked list of pidl structs
+ */
+
+void free_pidlist(
+
+  struct pidl *pl)
+
+  {
+  if(pl != NULL)
+    {
+    if(pl->next != NULL)
+      free_pidlist(pl->next);
+    free(pl);
+    }
+  } /* END free_pidlist() */
+
