@@ -105,7 +105,6 @@
 #include "pbs_error.h"
 #include "log.h"
 #include "svrfunc.h"
-#include "utils.h"
 
 #include <pwd.h>
 #include "mom_func.h"
@@ -120,10 +119,9 @@ extern int  svr_chkque(job *, pbs_queue *, char *, int, char *);
 extern int  job_route(job *);
 extern void check_state(int);
 extern void mom_server_all_update_stat();
-#ifdef NVIDIA_GPUS
 extern void mom_server_all_update_gpustat(void);
-extern int  use_nvidia_gpu;
-#endif  /* NVIDIA_GPUS */
+extern int  multi_mom;
+extern unsigned int pbs_rm_port;
 
 /* Global Data Items: */
 
@@ -458,7 +456,7 @@ void req_quejob(
       pj->ji_qs.ji_un.ji_newt.ji_fromaddr = get_connectaddr(sock);
       pj->ji_qs.ji_un.ji_newt.ji_scriptsz = 0;
 
-      /* Per Eric R., req_mvjobfile was giving error in open_std_file,
+      /* Per Eric R., req_mvjobfile was giving error in open_std_file, 
          showed up as fishy error message */
 
       if (pj->ji_grpcache != NULL)
@@ -483,9 +481,9 @@ void req_quejob(
 
   pj->ji_qs.ji_substate = JOB_SUBSTATE_TRANSIN;
 
-  pj->ji_wattr[(int)JOB_ATR_mtime].at_val.at_long = (long)time_now;
+  pj->ji_wattr[JOB_ATR_mtime].at_val.at_long = (long)time_now;
 
-  pj->ji_wattr[(int)JOB_ATR_mtime].at_flags |= ATR_VFLAG_SET;
+  pj->ji_wattr[JOB_ATR_mtime].at_flags |= ATR_VFLAG_SET;
 
   pj->ji_qs.ji_un_type = JOB_UNION_TYPE_NEW;
 
@@ -565,6 +563,7 @@ void req_jobscript(
 
   int  fds;
   char  namebuf[MAXPATHLEN];
+  char  portname[MAXPATHLEN];
   job *pj;
   int  filemode = 0700;
   extern char mom_host[];
@@ -622,6 +621,12 @@ void req_jobscript(
   strcpy(namebuf, path_jobs);
 
   strcat(namebuf, pj->ji_qs.ji_fileprefix);
+  if (multi_mom)
+    {
+    sprintf(portname, "%d", pbs_rm_port);
+    strcat(namebuf, portname);
+    }
+
   strcat(namebuf, JOB_SCRIPT_SUFFIX);
 
   if (pj->ji_qs.ji_un.ji_newt.ji_scriptsz == 0)
@@ -741,7 +746,7 @@ void req_mvjobfile(
     return;
     }
 
-  if ((pwd = getpwnam_ext(pj->ji_wattr[(int)JOB_ATR_euser].at_val.at_str)) == NULL)
+  if ((pwd = getpwnam(pj->ji_wattr[JOB_ATR_euser].at_val.at_str)) == NULL)
     {
     /* FAILURE */
     req_reject(PBSE_MOMREJECT, 0, preq, NULL, "password lookup failed");
@@ -753,7 +758,7 @@ void req_mvjobfile(
     {
     int keeping = 1;
     char *path = std_file_name(pj, jft, &keeping);
-
+    
     snprintf(log_buffer,sizeof(log_buffer),
       "Cannot create file %s",
       path);
@@ -817,6 +822,7 @@ void req_rdytocommit(
   int  OrigSState;
   char OrigSChar;
   long OrigFlags;
+  uint16_t momport = 0;
 
   pj = locate_new_job(sock, preq->rq_ind.rq_rdytocommit);
 
@@ -854,15 +860,20 @@ void req_rdytocommit(
   OrigState  = pj->ji_qs.ji_state;
 
   OrigSState = pj->ji_qs.ji_substate;
-  OrigSChar  = pj->ji_wattr[(int)JOB_ATR_state].at_val.at_char;
-  OrigFlags  = pj->ji_wattr[(int)JOB_ATR_state].at_flags;
+  OrigSChar  = pj->ji_wattr[JOB_ATR_state].at_val.at_char;
+  OrigFlags  = pj->ji_wattr[JOB_ATR_state].at_flags;
 
   pj->ji_qs.ji_state    = JOB_STATE_TRANSIT;
   pj->ji_qs.ji_substate = JOB_SUBSTATE_TRANSICM;
-  pj->ji_wattr[(int)JOB_ATR_state].at_val.at_char = 'T';
-  pj->ji_wattr[(int)JOB_ATR_state].at_flags |= ATR_VFLAG_SET;
+  pj->ji_wattr[JOB_ATR_state].at_val.at_char = 'T';
+  pj->ji_wattr[JOB_ATR_state].at_flags |= ATR_VFLAG_SET;
 
-  if (job_save(pj, SAVEJOB_NEW) == -1)
+  if (multi_mom)
+    {
+    momport = pbs_rm_port;
+    }
+
+  if (job_save(pj, SAVEJOB_NEW, momport) == -1)
     {
     char tmpLine[1024];
 
@@ -876,8 +887,8 @@ void req_rdytocommit(
 
     pj->ji_qs.ji_state    = OrigState;
     pj->ji_qs.ji_substate = OrigSState;
-    pj->ji_wattr[(int)JOB_ATR_state].at_val.at_char = OrigSChar;
-    pj->ji_wattr[(int)JOB_ATR_state].at_flags = OrigFlags;
+    pj->ji_wattr[JOB_ATR_state].at_val.at_char = OrigSChar;
+    pj->ji_wattr[JOB_ATR_state].at_flags = OrigFlags;
 
     req_reject(PBSE_SYSTEM, 0, preq, NULL, tmpLine);
 
@@ -935,6 +946,7 @@ void req_commit(
 
   {
   job   *pj;
+  unsigned int momport = 0;
 
   pj = locate_new_job(preq->rq_conn, preq->rq_ind.rq_commit);
 
@@ -993,7 +1005,7 @@ void req_commit(
       PBSEVENT_JOB,
       PBS_EVENTCLASS_JOB,
       (pj != NULL) ? pj->ji_qs.ji_jobid : "NULL",
-      "starting job execution");
+      "req_commit:starting job execution");
     }
 
   start_exec(pj);
@@ -1004,7 +1016,7 @@ void req_commit(
       PBSEVENT_JOB,
       PBS_EVENTCLASS_JOB,
       (pj != NULL) ? pj->ji_qs.ji_jobid : "NULL",
-      "job execution started");
+      "req_commit:job execution started");
     }
 
   /* if start request fails, reply with failure string */
@@ -1041,15 +1053,18 @@ void req_commit(
     reply_jobid(preq, pj->ji_qs.ji_jobid, BATCH_REPLY_CHOICE_Commit);
     }
 
-  job_save(pj, SAVEJOB_FULL);
+  if (multi_mom)
+    {
+    momport = pbs_rm_port;
+    }
+  job_save(pj, SAVEJOB_FULL, momport);
 
 #ifdef NVIDIA_GPUS
   /*
    * Does this job have a gpuid assigned?
    * if so, then update gpu status
    */
-  if ((use_nvidia_gpu) && 
-      ((pj->ji_wattr[JOB_ATR_exec_gpus].at_flags & ATR_VFLAG_SET) != 0) &&
+  if (((pj->ji_wattr[JOB_ATR_exec_gpus].at_flags & ATR_VFLAG_SET) != 0) &&
       (pj->ji_wattr[JOB_ATR_exec_gpus].at_val.at_str != NULL))
     {
     mom_server_all_update_gpustat();
