@@ -92,10 +92,10 @@
 #include "Parser.h"
 #include "af.h"
 
-static char ident[] = "@(#) $RCSfile$ $Revision: 2367 $";
+static char ident[] = "@(#) $RCSfile$ $Revision: 3230 $";
 
 extern void
-  yyerror A_((char *ep));
+  yyerror(char *ep);
 
 extern int  linenum;
 extern char linebuf[];
