@@ -259,6 +259,7 @@ int   server_init_type = RECOV_WARM;
 char         server_name[PBS_MAXSERVERNAME + 1]; /* host_name[:service|port] */
 int  svr_delay_entry = 0;
 int  svr_do_schedule = SCH_SCHEDULE_NULL;
+extern int  listener_command;
 tlist_head svr_queues;            /* list of queues                   */
 tlist_head svr_alljobs;           /* list of all jobs in server       */
 tlist_head svr_jobs_array_sum;    /* list of jobs in server, arrays summarized as single "placeholder" job */
@@ -504,6 +505,7 @@ clear_listeners(void)   /* I */
     listener_conns[i].address = 0;
     listener_conns[i].port = 0;
     listener_conns[i].sock = -1;
+    listener_conns[i].first_time = 1;
     }
 
   return;
@@ -785,6 +787,8 @@ void parse_command_line(int argc, char *argv[])
 
       case 'l':
 
+        clear_listeners();
+
         if (get_port(
               optarg,
               &listener_port,
@@ -1015,7 +1019,10 @@ static time_t next_task()
   /* should the scheduler be run?  If so, adjust the delay time  */
 
   if ((delay = server.sv_next_schedule - time_now) <= 0)
+    {
     svr_do_schedule = SCH_SCHEDULE_TIME;
+    listener_command = SCH_SCHEDULE_TIME;
+    }
   else if (delay < tilwhen)
     tilwhen = delay;
 
@@ -2109,10 +2116,10 @@ int is_ha_lock_file_valid(
 
   if (stat(LockDir,&Stat) != 0)
     {
-    char tmpLine[MAX_LINE];
+    char *tmpLine;
 
     /* stat failed */
-    strerror_r(errno,ErrorString,sizeof(ErrorString));
+    tmpLine = strerror(errno);
 
     snprintf(tmpLine,sizeof(tmpLine),"could not stat the lockfile dir '%s': %s",
       LockDir,
@@ -2382,12 +2389,12 @@ void *update_ha_lock_thread(
 
     if ((rc == -1) && !ISEMPTYSTR(HALockFile))
       {
-      char ErrorString[MAX_LINE];
+      char *ErrorString;
       /* error occurred--immediate shutdown needed */
 
       if (LocalErrno != 0)
         {
-        strerror_r(LocalErrno,ErrorString,sizeof(ErrorString));
+        ErrorString = strerror(LocalErrno);
 
         sprintf(log_buffer,"could not update HA lock file '%s' in heartbeat thread (%s - errno %d:%s)",
           HALockFile,
@@ -2568,10 +2575,7 @@ static void lock_out_ha()
 
     NumChecks++;
 
-    if (is_ha_lock_file_valid(HALockFile) == FALSE)
-      {
-      UseFLock = TRUE;
-      }
+    UseFLock = is_ha_lock_file_valid(HALockFile);
 
     if (UseFLock == TRUE)
       {
