@@ -580,11 +580,8 @@ jump:
        * Create a new batch request and fill it in. It will be freed by reply_ack
        */
 
-      LOG_EVENT(
-        PBSEVENT_JOB,
-        PBS_EVENTCLASS_JOB,
-        pjob->ji_qs.ji_jobid,
-        log_buffer);
+      snprintf(log_buffer,sizeof(log_buffer), "Deleting job asynchronously");
+      log_event(PBSEVENT_JOB,PBS_EVENTCLASS_JOB,pjob->ji_qs.ji_jobid,log_buffer);
 
       preq_tmp = alloc_br(PBS_BATCH_DeleteJob);
       preq_tmp->rq_perm = preq->rq_perm;
@@ -1141,11 +1138,10 @@ void remove_job_delete_nanny(
 
 struct work_task *apply_job_delete_nanny(
 
-        struct job *pjob,
-        int         delay)  /* I */
+  struct job *pjob,
+  int         delay)  /* I */
 
   {
-
   struct work_task *pwtnew;
   enum work_type tasktype;
 
