@@ -384,6 +384,7 @@ void req_quejob(
   pbs_queue *pque;
   char  *qname;
   attribute  tempattr;
+  struct stat stat_buf;
   char           EMsg[1024];
 
   /* set basic (user) level access permission */
@@ -418,6 +419,7 @@ void req_quejob(
     }
   else
     {
+    /* Create a job id */
     char host_server[PBS_MAXSERVERNAME + 1];
     int  server_suffix = TRUE;
 
@@ -787,6 +789,41 @@ void req_quejob(
         }
       }
 
+    /* check if a job id was supplied, and if so overwrite the job id */
+    if (pj->ji_wattr[JOB_ATR_job_id].at_flags & ATR_VFLAG_SET)
+      {
+      char *dot = strchr(pj->ji_qs.ji_jobid,'.');
+      char  tmp_extension[PBS_MAXSVRJOBID + 1];
+      job  *tmpjob;
+
+      if (dot != NULL)
+        {
+        strcpy(tmp_extension,dot);
+
+        snprintf(pj->ji_qs.ji_jobid, sizeof(pj->ji_qs.ji_jobid),
+          "%s%s",
+          pj->ji_wattr[JOB_ATR_job_id].at_val.at_str,
+          tmp_extension);
+        }
+      else
+        {
+        strcpy(pj->ji_qs.ji_jobid,pj->ji_wattr[JOB_ATR_job_id].at_val.at_str);
+        }
+
+      if ((tmpjob = find_job(pj->ji_qs.ji_jobid)) != NULL)
+        {
+        /* not unique, reject job */
+        job_purge(pj);
+
+        snprintf(log_buffer,sizeof(log_buffer),
+          "Job with id %s already exists, cannot set job id\n",
+          pj->ji_qs.ji_jobid);
+        req_reject(PBSE_JOBEXIST,0,preq,NULL,log_buffer);
+
+        return;
+        }
+      }
+
     /* set job owner attribute to user@host */
 
     job_attr_def[JOB_ATR_job_owner].at_free(
@@ -879,6 +916,36 @@ void req_quejob(
           pj->ji_wattr[JOB_ATR_outpath].at_val.at_str,
           (int)'o')));
       }
+    else if (pj->ji_wattr[JOB_ATR_outpath].at_flags & ATR_VFLAG_SET)
+      {
+      /* check to see if the path pointed to is a directory. If so apendd the default output file name.
+         Otherwise we treat the string as a path to a file */
+      char *ptr;
+
+      ptr = strchr(pj->ji_wattr[JOB_ATR_outpath].at_val.at_str, ':');
+      if(ptr)
+        {
+        ptr++;
+        rc = stat(ptr, &stat_buf);
+        }
+      else 
+        {
+        rc = stat(pj->ji_wattr[JOB_ATR_outpath].at_val.at_str, &stat_buf);
+        }
+      if(rc == 0)
+        {
+        if(S_ISDIR(stat_buf.st_mode))
+          {
+/*          strcat(pj->ji_wattr[JOB_ATR_outpath].at_val.at_str, "/"); */
+          replace_attr_string(
+            &pj->ji_wattr[JOB_ATR_outpath],
+            (add_std_filename(pj,
+            pj->ji_wattr[JOB_ATR_outpath].at_val.at_str,
+            (int)'o')));
+      
+          }
+        }
+      }
 
     if (!(pj->ji_wattr[JOB_ATR_errpath].at_flags & ATR_VFLAG_SET) ||
         (((pj->ji_wattr[JOB_ATR_errpath].at_val.at_str[strlen(pj->ji_wattr[JOB_ATR_errpath].at_val.at_str) - 1] == ':'))))
@@ -903,6 +970,36 @@ void req_quejob(
           pj->ji_wattr[JOB_ATR_errpath].at_val.at_str,
           (int)'e')));
       }
+    else if (pj->ji_wattr[JOB_ATR_errpath].at_flags & ATR_VFLAG_SET)
+      {
+        /* check to see if the path pointed to is a directory. If so apendd the default output file name.
+           Otherwise we treat the string as a path to a file */
+      char *ptr;
+
+      ptr = strchr(pj->ji_wattr[JOB_ATR_errpath].at_val.at_str, ':');
+      if(ptr)
+        {
+        ptr++;
+        rc = stat(ptr, &stat_buf);
+        }
+      else 
+        {
+        rc = stat(pj->ji_wattr[JOB_ATR_errpath].at_val.at_str, &stat_buf);
+        }
+      if(rc == 0)
+        {
+        if(S_ISDIR(stat_buf.st_mode))
+          {
+/*          strcat(pj->ji_wattr[JOB_ATR_outpath].at_val.at_str, "/"); */
+          replace_attr_string(
+            &pj->ji_wattr[JOB_ATR_errpath],
+            (add_std_filename(pj,
+            pj->ji_wattr[JOB_ATR_errpath].at_val.at_str,
+            (int)'e')));
+      
+          }
+        }
+      }
 
     if ((pj->ji_wattr[JOB_ATR_outpath].at_val.at_str == NULL) ||
         (pj->ji_wattr[JOB_ATR_errpath].at_val.at_str == NULL))
@@ -1216,17 +1313,19 @@ void req_jobscript(
     {
     if (errno == 0)
       {
-      sprintf(log_buffer, "job %s in unexpected state '%s'",
-              pj->ji_qs.ji_jobid,
-              PJobSubState[pj->ji_qs.ji_substate]);
+      snprintf(log_buffer, sizeof(log_buffer),
+        "job %s in unexpected state '%s'",
+        pj->ji_qs.ji_jobid,
+        PJobSubState[pj->ji_qs.ji_substate]);
       }
     else
       {
-      sprintf(log_buffer, "job %s in unexpected state '%s' (errno=%d - %s)",
-              pj->ji_qs.ji_jobid,
-              PJobSubState[pj->ji_qs.ji_substate],
-              errno,
-              strerror(errno));
+      snprintf(log_buffer, sizeof(log_buffer),
+        "job %s in unexpected state '%s' (errno=%d - %s)",
+        pj->ji_qs.ji_jobid,
+        PJobSubState[pj->ji_qs.ji_substate],
+        errno,
+        strerror(errno));
       }
 
     log_err(errno, id, log_buffer);
@@ -1427,9 +1526,10 @@ void req_mvjobfile(  /* NOTE:  routine for server only - mom code follows this r
 
   if (LOGLEVEL >= 6)
     {
-    sprintf(log_buffer, "successfully moved file '%s' for job '%s'",
-            namebuf,
-            preq->rq_ind.rq_jobfile.rq_jobid);
+    snprintf(log_buffer, sizeof(log_buffer),
+      "successfully moved file '%s' for job '%s'",
+      namebuf,
+      preq->rq_ind.rq_jobfile.rq_jobid);
 
     log_record(
       PBSEVENT_JOB,
@@ -1545,9 +1645,10 @@ void req_rdytocommit(
     {
     char tmpLine[1024];
 
-    sprintf(tmpLine, "cannot save job - errno=%d - %s",
-            errno,
-            strerror(errno));
+    snprintf(tmpLine, sizeof(tmpLine),
+      "cannot save job - errno=%d - %s",
+      errno,
+      strerror(errno));
 
     log_err(errno, id, tmpLine);
 
@@ -1571,9 +1672,10 @@ void req_rdytocommit(
     {
     /* reply failed, purge the job and close the connection */
 
-    sprintf(log_buffer, "cannot report jobid - errno=%d - %s",
-            errno,
-            strerror(errno));
+    snprintf(log_buffer, sizeof(log_buffer),
+      "cannot report jobid - errno=%d - %s",
+      errno,
+      strerror(errno));
 
     log_err(errno, id, log_buffer);
 
@@ -1863,11 +1965,12 @@ void req_commit(
 
   /* need to format message first, before request goes away */
 
-  sprintf(log_buffer, msg_jobnew,
-          preq->rq_user, preq->rq_host,
-          pj->ji_wattr[JOB_ATR_job_owner].at_val.at_str,
-          pj->ji_wattr[JOB_ATR_jobname].at_val.at_str,
-          pj->ji_qhdr->qu_qs.qu_name);
+  snprintf(log_buffer, sizeof(log_buffer),
+    msg_jobnew,
+    preq->rq_user, preq->rq_host,
+    pj->ji_wattr[JOB_ATR_job_owner].at_val.at_str,
+    pj->ji_wattr[JOB_ATR_jobname].at_val.at_str,
+    pj->ji_qhdr->qu_qs.qu_name);
 
   /* acknowledge the request with the job id */
 
@@ -1902,8 +2005,10 @@ void req_commit(
     {
     if (LOGLEVEL >= 7)
       {
-      sprintf(log_buffer, "Trying to AUTORUN job %s",
-              pj->ji_qs.ji_jobid);
+      snprintf(log_buffer, sizeof(log_buffer),
+        "Trying to AUTORUN job %s",
+        pj->ji_qs.ji_jobid);
+
       log_record(
         PBSEVENT_JOB,
         PBS_EVENTCLASS_JOB,
