@@ -150,6 +150,7 @@ extern tlist_head svr_queues;
 extern int    comp_resc_lt;
 extern int    comp_resc_gt;
 extern int    svr_do_schedule;
+extern int    listener_command;
 extern int    LOGLEVEL;
 
 extern time_t time_now;
@@ -530,6 +531,7 @@ int svr_enquejob(
       
     /* notify the scheduler we have a new job */
     svr_do_schedule = SCH_SCHEDULE_NEW;
+    listener_command = SCH_SCHEDULE_NEW;
     }
   else if (pque->qu_qs.qu_type == QTYPE_RoutePush)
     {
@@ -642,6 +644,7 @@ void svr_dequejob(
   /* notify scheduler a job has been removed */
 
   svr_do_schedule = SCH_SCHEDULE_TERM;
+  listener_command = SCH_SCHEDULE_TERM;
 
   return;
   }  /* END svr_dequejob() */
@@ -717,6 +720,7 @@ int svr_setjobstate(
             (newstate == JOB_STATE_QUEUED))
           {
           svr_do_schedule = SCH_SCHEDULE_NEW;
+          listener_command = SCH_SCHEDULE_NEW;
 
           if ((pjob->ji_wattr[JOB_ATR_etime].at_flags & ATR_VFLAG_SET) == 0)
             {
@@ -1532,7 +1536,7 @@ int svr_chkque(
 
   /*
    * 1. If the queue is an Execution queue ...
-   *    These is checked first because 1a - 1c are more damaging
+   *    This is checked first because 1a - 1c are more damaging
    *    (see local_move() in svr_movejob.c)
    */
 
@@ -1549,7 +1553,7 @@ int svr_chkque(
         }
       }
 
-    /* 1b. check site restrictions */
+    /* 1b. check site restrictions -- Currently site_acl_check is a stub */
 
     if (site_acl_check(pjob, pque))
       {
@@ -1960,19 +1964,6 @@ int svr_chkque(
 
       return(i);
       }
-    else
-      {
-      if (strcmp(pque->qu_attr->at_val.at_str, "Execution") == 0)
-        {
-        /* job routed to Execution queue successfully */
-        /* unset job's procct resource */
-        resource_def *pctdef;
-        resource *pctresc;
-        pctdef = find_resc_def(svr_resc_def, "procct", svr_resc_size);
-        if ((pctresc = find_resc_entry(&pjob->ji_wattr[JOB_ATR_resource], pctdef)) != NULL)
-           pctdef->rs_free(&pctresc->rs_value);
-        }
-      }
     }    /* END if (mtype != MOVE_TYPE_MgrMv) */
 
   /* SUCCESS - job can enter queue */
@@ -2159,6 +2150,21 @@ static void default_std(
 
 #endif
 
+  if (*pd == '[')
+    {
+    pd++;
+
+    if (isdigit(*pd))
+      {
+      *(to + len++) = '-';
+
+      while (isdigit(*pd))
+        {
+        *(to + len++) = *pd++;
+        }
+      }
+    }
+
   *(to + len) = '\0';
 
   return;
@@ -2424,7 +2430,7 @@ void set_resc_deflt(
 
 #ifdef RESOURCEMAXDEFAULT
   set_deflt_resc(ja, &pque->qu_attr[QA_ATR_ResourceMax]);
-
+/* http://www.adaptivecomputing.com/resources/docs/torque/4.2high-availability.php */
   /* server max limits will only be applied to attributes which have
      not yet been set */
 
@@ -2447,12 +2453,15 @@ void set_resc_deflt(
       }
     }
   
-  /* unset the procct resource if it has been set */
-  pctdef = find_resc_def(svr_resc_def, "procct", svr_resc_size);
-
-  if ((pctresc = find_resc_entry(ja, pctdef)) != NULL)
-    pctdef->rs_free(&pctresc->rs_value);
-
+  if (pque->qu_qs.qu_type == QTYPE_Execution)
+    {
+    /* unset the procct resource if it has been set */
+    pctdef = find_resc_def(svr_resc_def, "procct", svr_resc_size);
+ 
+    if ((pctresc = find_resc_entry(ja, pctdef)) != NULL)
+      pctdef->rs_free(&pctresc->rs_value);
+    }
+ 
   return;
   }  /* END set_resc_deflt() */
 
