@@ -315,7 +315,7 @@ static int local_move(
 
   jobp->ji_lastdest = 0; /* reset in case of another route */
 
-  job_save(jobp, SAVEJOB_FULL);
+  job_save(jobp, SAVEJOB_FULL, 0);
 
   return(0);
   }  /* END local_move() */
@@ -579,8 +579,6 @@ int send_job(
 
   char  *id = "send_job";
 
-  char   job_id[PBS_MAXSVRJOBID + 1];
-
   attribute *pattr;
 
   pid_t  pid;
@@ -807,10 +805,7 @@ int send_job(
 
   strcat(script_name, JOB_SCRIPT_SUFFIX);
 
-  /* save the job id for when after we purge the job */
-
-  strcpy(job_id, jobp->ji_qs.ji_jobid);
-
+ 
   pbs_errno = 0;
   con = -1;
 
@@ -874,7 +869,7 @@ int send_job(
         {
         jobp->ji_qs.ji_substate = JOB_SUBSTATE_TRNOUT;
 
-        job_save(jobp, SAVEJOB_QUICK);
+        job_save(jobp, SAVEJOB_QUICK, 0);
         }
 
       pqjatr = &((svrattrl *)GET_NEXT(attrl))->al_atopl;
@@ -952,7 +947,7 @@ int send_job(
 
       jobp->ji_qs.ji_substate = JOB_SUBSTATE_TRNOUTCM;
 
-      job_save(jobp, SAVEJOB_QUICK);
+      job_save(jobp, SAVEJOB_QUICK, 0);
       }
     else
       {
@@ -962,7 +957,7 @@ int send_job(
         log_err(errno, id, "sigprocmask\n");
       }
 
-    if (PBSD_rdytocmt(con, job_id) != 0)
+    if (PBSD_rdytocmt(con, jobp->ji_qs.ji_jobid) != 0)
       {
       if (sigprocmask(SIG_UNBLOCK, &all_set, NULL) == -1)
         log_err(errno, id, "sigprocmask\n");
@@ -970,15 +965,8 @@ int send_job(
       continue;
       }
 
-    /*
-     * we are sure that the other side has everything, so we can
-     * safely purge the job
-     */
-
-    if (move_type != MOVE_TYPE_Exec) /* not if sending to MOM */
-      job_purge(jobp);
-
-    if ((rc = PBSD_commit(con, job_id)) != 0)
+   
+    if ((rc = PBSD_commit(con, jobp->ji_qs.ji_jobid)) != 0)
       {
       int errno2;
 
@@ -1025,7 +1013,7 @@ int send_job(
 
         exit(1);
         }
-      }    /* END if ((rc = PBSD_commit(con,job_id)) != 0) */
+      }    /* END if ((rc = PBSD_commit(con,jobp->ji_qs.ji_jobid)) != 0) */
 
     svr_disconnect(con);
 
